#import <objectbase/SwarmObject.h>
#import <logzone/MemLogConsumer.h>

@interface RMemLogger: SwarmObject <MemLogConsumer>
{
	id myStream;
	id myObjects;
	BOOL isCumulative;
	int lastTime;
}
+ create: aZone fileName: (const char*) fname;
+ createBegin: aZone;
- (void) setCumulative;
- (void)setFilename: (char*) fname;
- (void)setOutputStream: aStream;
- createEnd;
- (void)consumeRecordTime: (timeval_t) aTime alloc: (int) i\
   classname: (const char*) cname address: (void*) addr size: (long) size;
@end
